/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*                       DIRECCIN DE PRUEBAS Y MEDICIN
/*                           SUBDIRECCION DE ANLISIS
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                     SEXTO GRADO DE PRIMARIA (Excale 06)
/*
/*                        **** DIRECTORES CONTEXTO ****
/*
/*                     Ciclo escolar evaluado: 2008 - 2009
/*_____________________________________________________________________________
/*
/*
/*       PROGRAMA PARA CONSTRUIR LA BASE DE DATOS DE DIRECTORES DE CONTEXTO
/*                                EN FORMATO SAS
/*_____________________________________________________________________________
/*
/*  El programa convierte al archivo Excale06_2009_Dir_Cuest.txt, el cual est en
/*  formato ASCII, en una base de datos en formato SAS. El programa realiza las
/*  siguientes tareas:
/*   - Declara formatos para algunas variables
/*   - Lee las variables del archivo en formato ASCII
/*   - Declara los valores considerados en el anlisis como perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale06_2009_Dir_Cuest.txt
/*         as como el archivo Excale06_2009_Dir_Cuest.SAS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE (www.inee.edu.mx).
/*      2) Modificar la primera y segunda lnea de los comandos de este archivo
/*         (libname y filename) para actualizar el nombre de la librera y el archivo
/*         de trabajo.
/*      3) Ejecutar el programa del archivo.
/*
/*  Al finalizar, se deber contar con la base de datos (tabla de datos) Excale06_2009_Dir_Cuest.sas7bdat
/*
/*  Posteriormente, cuando se desee utilizar nuevamente la base Excale06_2009_Dir_Cuest.sas7bdat,
/*  se deber ejecutar primero el procedimiento FORMAT ("proc FORMAT") de este programa para que
/*  SAS cargue los formatos necesarios para abrir la base.
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Subdireccin de Anlisis del Instituto
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 1082
/*      Domicilio: Jos Ma. Velasco No. 101. 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE LIBERACIN: 20 DE ABRIL DE 2012
/*
/*  ****************************************************************************/


LIBNAME  INEE  "C:\***\";
FILENAME dir   "C:\***\Excale06_2009_Dir_Cuest.TXT";

PROC FORMAT;
     VALUE id_entF     1         = "Aguascalientes"
                       2         = "Baja California"
                       3         = "Baja California Sur"
                       4         = "Campeche"
                       5         = "Coahuila"
                       6         = "Colima"
                       7         = "Chiapas"
                       8         = "Chihuahua"
                       9         = "Distrito Federal"
                       10        = "Durango"
                       11        = "Guanajuato"
                       12        = "Guerrero"
                       13        = "Hidalgo"
                       14        = "Jalisco"
                       15        = "Mxico"
                       16        = "Michoacn"
                       17        = "Morelos"
                       18        = "Nayarit"
                       19        = "Nuevo Len"
                       20        = "Oaxaca"
                       21        = "Puebla"
                       22        = "Quertaro"
                       23        = "Quintana Roo"
                       24        = "San Luis Potos"
                       25        = "Sinaloa"
                       26        = "Sonora"
                       27        = "Tabasco"
                       28        = "Tamaulipas"
                       29        = "Tlaxcala"
                       30        = "Veracruz"
                       31        = "Yucatn"
                       32        = "Zacatecas";
     VALUE id_modF     1         ="Urbana Pblica"
                       2         ="Rural Pblica"
                       3         ="Educacin Indgena"
                       4         ="Curso Comunitario"
                       5         ="Privada"
                       6         ="General"
                       7         ="Tcnica"
                       8         ="Telesecundaria"
                       9         ="Privada";
     VALUE $modF       "UP"      ="Urbano Pblico"
                       "RP"      ="Rural Pblico"
                       "EI"      ="Educacin Indgena"
                       "CC"      ="Cursos Comunitarios"
                       "UPV"     ="Privados"
                       "GRAL"    ="General"
                       "TEC"     ="Tcnica"
                       "TV"      ="Telesecundaria"
                       "PRIV"    ="Privada";
     VALUE $gmF        "1"       ="Muy alto"
                       "2"       ="Alto"
                       "3"       ="Medio"
                       "4"       ="Bajo"
                       "5"       ="Muy bajo"
                       "9"       ="Perdido"
                       "NA"      ="No aplica";
     VALUE marg_urF    1         ="Alta marginacin"
                       2         ="Baja marginacin"
                       7         ="No aplica";
     VALUE DP001F      1         ="Hombre"
                       2         ="Mujer"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE DP002F      1         ="Menos de 40"
                       2         ="Entre 40 y 49"
                       3         ="Entre 50 y 59"
                       4         ="60  ms"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE DP3_8F      1         ="S"
                       0         ="No"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE DP009F      1         ="Bachillerato o carrera tcnica"
                       2         ="Normal bsica"
                       3         ="Normal superior o licenciatura en educacin"
                       4         ="Otra licenciatura"
                       5         ="Posgrado"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE DP10_11F    1         ="S"
                       0         ="No"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE DP12_17F    0         ="No hay"
                       1         ="Malo"
                       2         ="Regular"
                       3         ="Bueno"
                       4         ="Excelente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE DP18_19F    1         ="S"
                       0         ="No"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE DP20_22F    0         ="No asisten"
                       1         ="Asisten pero no participan"
                       2         ="Asisten y participan"
                       3         ="Participan y hacen sugerencias"
                       4         ="Participan y coordinan actividades con otros padres"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE DP23_26F    1         ="Nunca o casi nunca"
                       2         ="A veces"
                       3         ="Frecuentemente"
                       4         ="Siempre o casi siempre"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE DP27_28F    1         ="S"
                       0         ="No"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE DP029F      1         ="4  horas o menos"
                       2         ="Entre 5 y 6 horas"
                       3         ="6  horas o ms"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE DP30_34F    0         ="No existe"
                       1         ="Existe solamente uno para todo el plantel"
                       2         ="Existe uno por grado"
                       3         ="Existe uno por grupo"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE DP035F      1         ="Menos de 100"
                       2         ="Entre 100 y 200"
                       3         ="Entre 200 y 400"
                       4         ="Ms de 400"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
RUN;



DATA INEE.Excale06_2009_Dir_Cuest;
   LENGTH
       NACIONAL           3
       ESCUELA            4
       ID_ENT             3
       NOM_ENT            $19
       ID_MOD             3
       MOD                $4
       GM                 $2
       MARG_URB           3
       ESTRATO            $7
       ENTEST             $6
       ID_INSTR           $12
       W_DIR              8
       DP001              3
       DP002              3
       DP003              3
       DP004              3
       DP005              3
       DP006              3
       DP007              3
       DP008              3
       DP009              3
       DP010              3
       DP011              3
       DP012              3
       DP013              3
       DP014              3
       DP015              3
       DP016              3
       DP017              3
       DP018              3
       DP019              3
       DP020              3
       DP021              3
       DP022              3
       DP023              3
       DP024              3
       DP025              3
       DP026              3
       DP027              3
       DP028              3
       DP029              3
       DP030              3
       DP031              3
       DP032              3
       DP033              3
       DP034              3
       DP035              3
       WVARSTRR           3
       W_FSTR1            8
       W_FSTR2            8
       W_FSTR3            8
       W_FSTR4            8
       W_FSTR5            8
       W_FSTR6            8
       W_FSTR7            8
       W_FSTR8            8
       W_FSTR9            8
       W_FSTR10           8
       W_FSTR11           8
       W_FSTR12           8
       W_FSTR13           8
       W_FSTR14           8
       W_FSTR15           8
       W_FSTR16           8
       W_FSTR17           8
       W_FSTR18           8
       W_FSTR19           8
       W_FSTR20           8
       W_FSTR21           8
       W_FSTR22           8
       W_FSTR23           8
       W_FSTR24           8
       W_FSTR25           8
       W_FSTR26           8
       W_FSTR27           8
       W_FSTR28           8
       W_FSTR29           8
       W_FSTR30           8
       W_FSTR31           8
       W_FSTR32           8
       W_FSTR33           8
       W_FSTR34           8
       W_FSTR35           8
       W_FSTR36           8
       W_FSTR37           8
       W_FSTR38           8
       W_FSTR39           8
       W_FSTR40           8
       W_FSTR41           8
       W_FSTR42           8
       W_FSTR43           8
       W_FSTR44           8
       W_FSTR45           8
       W_FSTR46           8
       W_FSTR47           8
       W_FSTR48           8
       W_FSTR49           8
       W_FSTR50           8
       W_FSTR51           8
       W_FSTR52           8
       W_FSTR53           8
       W_FSTR54           8
       W_FSTR55           8
       W_FSTR56           8
       W_FSTR57           8
       W_FSTR58           8
       W_FSTR59           8
       W_FSTR60           8
       W_FSTR61           8
       W_FSTR62           8
       W_FSTR63           8
       W_FSTR64           8
       W_FSTR65           8
       W_FSTR66           8
       W_FSTR67           8
       W_FSTR68           8
       W_FSTR69           8
       W_FSTR70           8
       W_FSTR71           8
       W_FSTR72           8
       W_FSTR73           8
       W_FSTR74           8
       W_FSTR75           8
       W_FSTR76           8
       W_FSTR77           8
       W_FSTR78           8
       W_FSTR79           8
       W_FSTR80           8
 ;

INFILE dir MISSOVER LINESIZE = 987;
   INPUT
       NACIONAL          1 - 1
       ESCUELA           2 - 5
       ID_ENT            6 - 7
       NOM_ENT           8 - 26
       ID_MOD           27 - 27
       MOD              28 - 31
       GM               32 - 33
       MARG_URB         34 - 34
       ESTRATO          35 - 41
       ENTEST           42 - 47
       ID_INSTR         48 - 59
       W_DIR            60 - 70
       DP001            71 - 71
       DP002            72 - 72
       DP003            73 - 73
       DP004            74 - 74
       DP005            75 - 75
       DP006            76 - 76
       DP007            77 - 77
       DP008            78 - 78
       DP009            79 - 79
       DP010            80 - 80
       DP011            81 - 81
       DP012            82 - 82
       DP013            83 - 83
       DP014            84 - 84
       DP015            85 - 85
       DP016            86 - 86
       DP017            87 - 87
       DP018            88 - 88
       DP019            89 - 89
       DP020            90 - 90
       DP021            91 - 91
       DP022            92 - 92
       DP023            93 - 93
       DP024            94 - 94
       DP025            95 - 95
       DP026            96 - 96
       DP027            97 - 97
       DP028            98 - 98
       DP029            99 - 99
       DP030           100 - 100
       DP031           101 - 101
       DP032           102 - 102
       DP033           103 - 103
       DP034           104 - 104
       DP035           105 - 105
       WVARSTRR        106 - 107
       W_FSTR1         108 - 118
       W_FSTR2         119 - 129
       W_FSTR3         130 - 140
       W_FSTR4         141 - 151
       W_FSTR5         152 - 162
       W_FSTR6         163 - 173
       W_FSTR7         174 - 184
       W_FSTR8         185 - 195
       W_FSTR9         196 - 206
       W_FSTR10        207 - 217
       W_FSTR11        218 - 228
       W_FSTR12        229 - 239
       W_FSTR13        240 - 250
       W_FSTR14        251 - 261
       W_FSTR15        262 - 272
       W_FSTR16        273 - 283
       W_FSTR17        284 - 294
       W_FSTR18        295 - 305
       W_FSTR19        306 - 316
       W_FSTR20        317 - 327
       W_FSTR21        328 - 338
       W_FSTR22        339 - 349
       W_FSTR23        350 - 360
       W_FSTR24        361 - 371
       W_FSTR25        372 - 382
       W_FSTR26        383 - 393
       W_FSTR27        394 - 404
       W_FSTR28        405 - 415
       W_FSTR29        416 - 426
       W_FSTR30        427 - 437
       W_FSTR31        438 - 448
       W_FSTR32        449 - 459
       W_FSTR33        460 - 470
       W_FSTR34        471 - 481
       W_FSTR35        482 - 492
       W_FSTR36        493 - 503
       W_FSTR37        504 - 514
       W_FSTR38        515 - 525
       W_FSTR39        526 - 536
       W_FSTR40        537 - 547
       W_FSTR41        548 - 558
       W_FSTR42        559 - 569
       W_FSTR43        570 - 580
       W_FSTR44        581 - 591
       W_FSTR45        592 - 602
       W_FSTR46        603 - 613
       W_FSTR47        614 - 624
       W_FSTR48        625 - 635
       W_FSTR49        636 - 646
       W_FSTR50        647 - 657
       W_FSTR51        658 - 668
       W_FSTR52        669 - 679
       W_FSTR53        680 - 690
       W_FSTR54        691 - 701
       W_FSTR55        702 - 712
       W_FSTR56        713 - 723
       W_FSTR57        724 - 734
       W_FSTR58        735 - 745
       W_FSTR59        746 - 756
       W_FSTR60        757 - 767
       W_FSTR61        768 - 778
       W_FSTR62        779 - 789
       W_FSTR63        790 - 800
       W_FSTR64        801 - 811
       W_FSTR65        812 - 822
       W_FSTR66        823 - 833
       W_FSTR67        834 - 844
       W_FSTR68        845 - 855
       W_FSTR69        856 - 866
       W_FSTR70        867 - 877
       W_FSTR71        878 - 888
       W_FSTR72        889 - 899
       W_FSTR73        900 - 910
       W_FSTR74        911 - 921
       W_FSTR75        922 - 932
       W_FSTR76        933 - 943
       W_FSTR77        944 - 954
       W_FSTR78        955 - 965
       W_FSTR79        966 - 976
       W_FSTR80        977 - 987
 ;

   LABEL
       NACIONAL    = "Variable auxiliar para obtener promedios nacionales"
       ESCUELA     = "Identificador de la escuela"
       ID_ENT      = "Entidad federativa (identificador numrico)"
       NOM_ENT     = "Entidad federativa"
       ID_MOD      = "Estrato escolar o Modalidad educativa (identificador numrico)"
       MOD         = "Estrato escolar o Modalidad educativa"
       GM          = "Clave de Grado de Marginacin Urbano oficial/Rural (AGEB/localidad)"
       MARG_URB    = "Marginalidad Urbana"
       ESTRATO     = "Estrato de muestreo. Se construy con ENTIDAD, MODALIDAD Y MARGINALIDAD. No es comn a todas las tablas pues en algunos casos se colapsaron registros"
       ENTEST      = "Estratos del diseo muestral con el que se estiman los parmetros y errores estndar (Entidad federativa-Modalidad-Densidad de poblacin)"
       ID_INSTR    = "Identificador del cuestionario"
       W_DIR       = "Peso muestral o ponderador del director"
       DP001       = "Es usted hombre o mujer?"
       DP002       = "Cuntos aos cumplidos tiene?"
       DP003       = "Tiene usted clave de director(a) de su plantel?"
       DP004       = "Adems de ser director(a), tiene a su cargo algn grupo en esta escuela?"
       DP005       = "Trabaja otro turno, como director(a) o docente, en esta o en otra escuela?"
       DP006       = "Adems de su trabajo en esta escuela, tiene otro empleo permanente por el cual reciba remuneracin?"
       DP007       = "Est usted incorporado a algn programa de estmulos de Carrera Magisterial?"
       DP008       = "Est usted incorporado a algn programa de estmulos diferente a Carrera Magisterial (escalafn, programas estatales, etctera)?"
       DP009       = "Cul es su nivel mximo de estudios?"
       DP010       = "La oferta de cursos de actualizacin a la que tiene acceso, satisface sus necesidades actuales?"
       DP011       = "Ha tomado cursos de actualizacin en instituciones distintas a la SEP en los ltimos dos aos?"
       DP012       = "En qu estado se encuentran las siguientes instalaciones de su plantel?: Los baos para alumnos"
       DP013       = "En qu estado se encuentran las siguientes instalaciones de su plantel?: Instalaciones deportivas"
       DP014       = "En qu estado se encuentran las siguientes instalaciones de su plantel?: Saln de usos mltiples"
       DP015       = "En qu estado se encuentran las siguientes instalaciones de su plantel?: Patio"
       DP016       = "En qu estado se encuentran las siguientes instalaciones de su plantel?: Biblioteca"
       DP017       = "En qu estado se encuentran las siguientes instalaciones de su plantel?: Sala de medios"
       DP018       = "Su plantel cuenta con conexin a Internet?"
       DP019       = "Su escuela cuenta con agua corriente todos los das de la semana?"
       DP020       = "Cmo es la participacin de los padres de familia en las siguientes actividades?: Cvico sociales"
       DP021       = "Cmo es la participacin de los padres de familia en las siguientes actividades?: Acadmicas"
       DP022       = "Cmo es la participacin de los padres de familia en las siguientes actividades?: Actividades culturales"
       DP023       = "Se presentan robos en los alrededores de su plantel?"
       DP024       = "Se presentan peleas con agresiones fsicas serias en los alrededores de su plantel?"
       DP025       = "Se consume alcohol en los alrededores de su plantel?"
       DP026       = "Se consumen drogas en los alrededores de su plantel?"
       DP027       = "Existen en su plantel maestros(as) que impartan dos o ms grados de forma simultnea en una misma aula?"
       DP028       = "Durante este ciclo escolar, tuvo su plantilla docente completa?"
       DP029       = "Cuntas horas pasan los estudiantes en la escuela, en un da normal?"
       DP030       = "Seale si en su plantel se dispone de los siguientes recursos: Grabadora o equipo de sonido"
       DP031       = "Seale si en su plantel se dispone de los siguientes recursos: Reproductor de pelculas"
       DP032       = "Seale si en su plantel se dispone de los siguientes recursos: Televisin"
       DP033       = "Seale si en su plantel se dispone de los siguientes recursos: Computadora"
       DP034       = "Seale si en su plantel se dispone de los siguientes recursos: Proyector para computadora o can"
       DP035       = "De cuntos libros dispone su escuela para que los alumnos consulten?"
       WVARSTRR    = "Identificador del pseudoestrato (1 a 80) definido para el clculo de errores estndar con el mtodo de remuestreo BRR"
       W_FSTR1     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR2     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR3     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR4     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR5     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR6     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR7     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR8     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR9     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR10    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR11    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR12    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR13    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR14    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR15    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR16    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR17    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR18    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR19    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR20    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR21    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR22    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR23    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR24    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR25    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR26    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR27    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR28    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR29    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR30    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR31    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR32    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR33    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR34    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR35    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR36    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR37    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR38    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR39    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR40    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR41    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR42    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR43    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR44    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR45    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR46    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR47    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR48    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR49    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR50    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR51    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR52    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR53    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR54    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR55    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR56    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR57    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR58    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR59    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR60    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR61    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR62    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR63    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR64    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR65    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR66    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR67    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR68    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR69    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR70    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR71    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR72    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR73    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR74    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR75    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR76    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR77    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR78    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR79    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR80    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
 ;

   FORMAT
        NACIONAL       1.
        ESCUELA        4.
        ID_ENT         id_entF.
        NOM_ENT        $char19.
        ID_MOD         id_modF.
        MOD            $modF.
        GM             $gmF.
        MARG_URB       marg_urF.
        ESTRATO        $char7.
        ENTEST         $char6.
        ID_INSTR       $char12.
        DP001          DP001F.
        DP002          DP002F.
        DP003          DP3_8F.
        DP004          DP3_8F.
        DP005          DP3_8F.
        DP006          DP3_8F.
        DP007          DP3_8F.
        DP008          DP3_8F.
        DP009          DP009F.
        DP010          DP10_11F.
        DP011          DP10_11F.
        DP012          DP12_17F.
        DP013          DP12_17F.
        DP014          DP12_17F.
        DP015          DP12_17F.
        DP016          DP12_17F.
        DP017          DP12_17F.
        DP018          DP18_19F.
        DP019          DP18_19F.
        DP020          DP20_22F.
        DP021          DP20_22F.
        DP022          DP20_22F.
        DP023          DP23_26F.
        DP024          DP23_26F.
        DP025          DP23_26F.
        DP026          DP23_26F.
        DP027          DP27_28F.
        DP028          DP27_28F.
        DP029          DP029F.
        DP030          DP30_34F.
        DP031          DP30_34F.
        DP032          DP30_34F.
        DP033          DP30_34F.
        DP034          DP30_34F.
        DP035          DP035F.
;


/**************************************************************************
/*  Definicin de valores perdidos
/*   .M o M = Respuesta Mltiple.
/*   .S o S = Respuesta omitida (No contestado).
/*************************************************************************/
   IF  GM = "9"  THEN  GM = .S;
   IF  GM = "NA"  THEN  GM = .S;
   IF  marg_urb = 7 THEN  marg_urb = .S;



   ARRAY perdidos1(35)
                   DP001 DP002 DP003 DP004 DP005 DP006 DP007 DP008
                   DP009 DP010 DP011 DP012 DP013 DP014 DP015 DP016
                   DP017 DP018 DP019 DP020 DP021 DP022 DP023 DP024
                   DP025 DP026 DP027 DP028 DP029 DP030 DP031 DP032
                   DP033 DP034 DP035;
   DO  i=1 TO 35;
          IF perdidos1{i} = 8   THEN  perdidos1{i} = .M;
          IF perdidos1{i} = 9   THEN  perdidos1{i} = .S;
   END;

   drop i;
RUN;

